Changelog
=========

.. rst-class:: lead

    Here lists the release notes of otpauth v2.

----

For **v1**, please head over to https://pythonhosted.org/otpauth/

2.2.1
-----

**Released on May 9, 2025**

- Avoid ``verify`` to raise an exception when the ``code`` argument is non-ascii.

2.2.0
-----

**Released on Mar 1, 2025**

- Add python 3.12, 3.13 supports.
- Rename RFC files to private filenames.

2.1.1
-----

**Released on Sep 09, 2023**

- Fix ``.verify`` method


2.1.0
-----

**Released on Jul 20, 2023**

- Improve type hints

2.0.0
-----

**Released on Mar 24, 2023**

New, rewrite completely.
